searchNodes=[{"doc":"Elixir module to help you write matchspecs. contains functions which transform elixir-style functions into erlang matchspecs, and vice versa. Functions to matchspecs For transforming elixir-style functions into matchspecs, the following restrictions apply: The function must use the Kernel.fn/1 macro as its form, or use defmatchspec/2 or defmatchspec/3 , where the matchspecs form is similar to the Kernel.fn/1 form.any() The function must have arity 1. The function may only use guards in its when section. The function may only return a single expression that uses guard functions to transform matches. Furthermore, the following restrictions apply to binary pattern matching in the head of the function the binary pattern may only consist of single bytes and strings arbitrary bit-width bitstrings are not supported conversions such as float are not supported. Note The restrictions on binary matching exist due to limitations on the BIFs available to ets and may change in the future if OTP comes to support these conversions in its kernel.","ref":"MatchSpec.html","title":"MatchSpec","type":"module"},{"doc":"Writes a matchspec-generating function based on a body. You may provide multiple function bodies. This macro uses the same backend as fun2msfun/4 and will generate identical code to that macro. Example: use MatchSpec defmatchspec my_matchspec ( value1 , value2 ) do { key , ^ value1 , ^ value } when key === :foo -&gt; value == value2 end This generates the equivalent to the following function: def my_matchspec ( value1 , value2 ) do [ { :&quot;$1&quot; , :&quot;$2&quot; , :&quot;$3&quot; } , [ { :&quot;=:=&quot; , :&quot;$1&quot; , :foo } , { :&quot;=:=&quot; , :&quot;$2&quot; , value1 } ] , [ { :== , :&quot;$3&quot; , { :const , value2 } } ] ] end","ref":"MatchSpec.html#defmatchspec/2","title":"MatchSpec.defmatchspec/2","type":"macro"},{"doc":"Writes a matchspec-generating function based on a body. You may provide multiple function bodies. This macro uses the same backend as fun2msfun/4 and will generate identical code. see defmatchspec/2 for details","ref":"MatchSpec.html#defmatchspecp/2","title":"MatchSpec.defmatchspecp/2","type":"macro"},{"doc":"converts a function ast into an ets matchspec. The function must also be &quot; fn ast&quot;; you can't pass a shorthand lambda or a lambda to an existing lambda. The function lambda form is only used as a scaffolding to represent ets matching and filtering operations, by default it will not be instantiated into bytecode of the resulting module. iex&gt; require MatchSpec iex&gt; MatchSpec . fun2ms ( fn tuple = { k , v } when v &gt; 1 and v &lt; 10 -&gt; tuple end ) [ { { :&quot;$1&quot; , :&quot;$2&quot; } , [ { :andalso , { :&gt; , :&quot;$2&quot; , 1 } , { :&lt; , :&quot;$2&quot; , 10 } } ] , [ :&quot;$_&quot; ] } ] If you would also like the equivalent lambda, pass with_fun: true as an option and the fun2ms/2 macro will emit a tuple of the matchspec and the lambda. iex&gt; { ms , fun } = MatchSpec . fun2ms ( fn { :key , value } -&gt; value end , with_fun : true ) iex&gt; :ets . test_ms ( { :key , &quot;value&quot; } , ms ) { :ok , &quot;value&quot; } iex&gt; fun . ( { :key , &quot;value&quot; } ) &quot;value&quot; This macro uses the same backend as fun2msfun/4 and will emit the same matchspec as if you passed no parameters to fun2msfun/4","ref":"MatchSpec.html#fun2ms/2","title":"MatchSpec.fun2ms/2","type":"macro"},{"doc":"converts a function into a function that generates a match spec based on bindings. This can be used to either create an named function or an anonymous function. if you would like to use one of the free variables in your function as a part of the head of the match, you must pin it. if you omit the first parameter, it will create an anonymous function. Example with :lambda (default): iex&gt; require MatchSpec iex&gt; lambda = MatchSpec . fun2msfun ( :lambda , fn { key , value } when key === target -&gt; value end , [ target ] ) iex&gt; lambda . ( :key ) [ { { :&quot;$1&quot; , :&quot;$2&quot; } , [ { :&quot;=:=&quot; , :&quot;$1&quot; , { :const , :key } } ] , [ :&quot;$2&quot; ] } ] iex&gt; lambda2 = MatchSpec . fun2msfun ( fn { ^ key , value } -&gt; value end , [ key ] ) iex&gt; lambda2 . ( :key ) [ { { :&quot;$1&quot; , :&quot;$2&quot; } , [ { :&quot;=:=&quot; , :&quot;$1&quot; , { :const , :key } } ] , [ :&quot;$2&quot; ] } ] Example with ( :def / :defp ): require MatchSpec MatchSpec . fun2msfun ( :def , :matchspec , fn { key , value } when key == target -&gt; value end , [ target ] )","ref":"MatchSpec.html#fun2msfun/4","title":"MatchSpec.fun2msfun/4","type":"macro"},{"doc":"converts a matchspec into elixir AST for functions. Unfortunately, the ast generator cannot guess names for variables, so variable names are set by the numerical value of the matchspec token The second parameter takes two modes: :ast emits elixir ast to write a lambda. iex&gt; MatchSpec . ms2fun ( [ { { :&quot;$1&quot; , :&quot;$2&quot; } , [ ] , [ :&quot;$2&quot; ] } ] , :ast ) { :fn , [ ] , [ { :-&gt; , [ ] , [ [ { :{} , [ ] , [ { :v1 , [ ] , nil } , { :v2 , [ ] , nil } ] } ] , { :v2 , [ ] , nil } ] } ] } :code outputs formatted elixir code. iex&gt; MatchSpec . ms2fun ( [ { { :&quot;$1&quot; , :&quot;$2&quot; } , [ ] , [ :&quot;$2&quot; ] } , { { :&quot;$1&quot; } , [ ] , [ :&quot;$_&quot; ] } ] , :code ) &quot;&quot;&quot; fn {v1, v2} -&gt; v2 tuple = {v1} -&gt; tuple end &quot;&quot;&quot;","ref":"MatchSpec.html#ms2fun/2","title":"MatchSpec.ms2fun/2","type":"function"},{"doc":"ets matchspec helper library for elixir. Exposes fun2ms and ms2fun functions which transform elixir-style functions into erlang matchspecs. iex&gt; require MatchSpec iex&gt; MatchSpec . fun2ms ( fn { key , value } when key === :foo -&gt; value end ) [ { { :&quot;$1&quot; , :&quot;$2&quot; } , [ { :&quot;=:=&quot; , :&quot;$1&quot; , { :const , :foo } } ] , [ :&quot;$2&quot; ] } ] iex&gt; MatchSpec . ms2fun ( [ { { :&quot;$1&quot; , :&quot;$2&quot; } , [ { :&quot;=:=&quot; , :&quot;$1&quot; , { :const , :foo } } ] , [ :&quot;$2&quot; ] } ] , :code ) &quot;fn {v1, v2} when v1 === :foo -&gt; v2 end&quot; iex&gt; :ets . test_ms ( { :foo , :bar } , MatchSpec . fun2ms ( fn { key , value } when key === :foo -&gt; value end ) ) { :ok , :bar }","ref":"readme.html","title":"MatchSpec","type":"extras"},{"doc":"The package can be installed by adding match_spec to your list of dependencies in mix.exs : def deps do [ { :match_spec , &quot;~&gt; 0.1.0&quot; } ] end Documentation can be generated with ExDoc and published on HexDocs . Once published, the docs can be found at https://hexdocs.pm/match_spec .","ref":"readme.html#installation","title":"MatchSpec - Installation","type":"extras"}]